@@ -1,7 +1,7 @@
 package Bencher::Scenario::ArraySet::Startup;
 
-our $DATE = '2016-09-16'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,7 +34,7 @@ Bencher::Scenario::ArraySet::Startup - Benchmark startup of Array::Set
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::ArraySet::Startup (from Perl distribution Bencher-Scenarios-ArraySet), released on 2016-09-16.
+This document describes version 0.003 of Bencher::Scenario::ArraySet::Startup (from Perl distribution Bencher-Scenarios-ArraySet), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -44,6 +44,10 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
@@ -86,19 +90,18 @@ Benchmark with C<< bencher -m ArraySet::Startup --include-path archive/Array-Set
 
  #table1#
  {dataset=>undef}
- +---------------------+--------+-----------+------------------------+------------+---------+---------+
- | participant         | modver | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+--------+-----------+------------------------+------------+---------+---------+
- | Set::Object         |        |      14   |                   12   |        1   | 6.8e-05 |      20 |
- | Set::Scalar         |        |      12   |                   10   |        1.1 | 2.2e-05 |      20 |
- | Array::Set          | 0.02   |       9.7 |                    7.7 |        1.4 | 2.7e-05 |      20 |
- | Array::Set          | 0.05   |       5.2 |                    3.2 |        2.6 | 3.2e-05 |      20 |
- | perl -e1 (baseline) |        |       2   |                    0   |        8   |   2e-05 |      20 |
- +---------------------+--------+-----------+------------------------+------------+---------+---------+
+ +-------------------------+---------------+-----------+---------------------+--------+-----------+------------------------+------------+---------+---------+
+ | proc_private_dirty_size | proc_rss_size | proc_size | participant         | modver | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +-------------------------+---------------+-----------+---------------------+--------+-----------+------------------------+------------+---------+---------+
+ | 1.9                     | 5.2           | 19        | Set::Object         |        |      14   |                   12   |        1   | 1.5e-05 |      20 |
+ | 0.83                    | 4.1           | 16        | Set::Scalar         |        |      13   |                   11   |        1.1 | 4.1e-05 |      21 |
+ | 2.2                     | 5.7           | 19        | Array::Set          | 0.02   |      10   |                    8   |        1.4 | 3.3e-05 |      20 |
+ | 2.2                     | 5.5           | 19        | Array::Set          | 0.05   |       5.4 |                    3.4 |        2.5 | 1.7e-05 |      20 |
+ | 1.1                     | 4.3           | 16        | perl -e1 (baseline) |        |       2   |                    0   |        6.9 | 1.3e-05 |      20 |
+ +-------------------------+---------------+-----------+---------------------+--------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -124,7 +127,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
