@@ -1,7 +1,7 @@
 package Bencher::Scenario::ArraySet::diff;
 
-our $DATE = '2016-09-16'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -57,7 +57,7 @@ Bencher::Scenario::ArraySet::diff - Benchmark diff operation
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::ArraySet::diff (from Perl distribution Bencher-Scenarios-ArraySet), released on 2016-09-16.
+This document describes version 0.003 of Bencher::Scenario::ArraySet::diff (from Perl distribution Bencher-Scenarios-ArraySet), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -71,6 +71,10 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
@@ -150,10 +154,10 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_diff    | 0.02   |       344 |     2.91  |       1    | 2.1e-06 |      22 |
- | Set::Scalar::difference |        |       410 |     2.4   |       1.2  | 8.9e-06 |      20 |
- | Set::Object::difference |        |      1450 |     0.689 |       4.22 | 6.4e-07 |      20 |
- | Array::Set::set_diff    | 0.05   |      3160 |     0.317 |       9.19 | 2.1e-07 |      20 |
+ | Array::Set::set_diff    | 0.02   |       340 |     2.9   |       1    | 3.6e-06 |      20 |
+ | Set::Scalar::difference |        |       390 |     2.6   |       1.1  | 1.4e-05 |      24 |
+ | Set::Object::difference |        |      1300 |     0.78  |       3.7  | 1.3e-06 |      20 |
+ | Array::Set::set_diff    | 0.05   |      3210 |     0.312 |       9.32 | 2.7e-07 |      20 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table2#
@@ -161,10 +165,10 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_diff    | 0.02   |       240 |     4.2   |       1    | 4.3e-06 |      20 |
- | Set::Scalar::difference |        |       390 |     2.6   |       1.6  |   1e-05 |      22 |
- | Set::Object::difference |        |      1420 |     0.705 |       6.02 | 4.3e-07 |      20 |
- | Array::Set::set_diff    | 0.05   |      3140 |     0.319 |      13.3  | 2.1e-07 |      20 |
+ | Array::Set::set_diff    | 0.02   |       237 |     4.22  |        1   | 2.9e-06 |      20 |
+ | Set::Scalar::difference |        |       300 |     3     |        1   | 5.4e-05 |      23 |
+ | Set::Object::difference |        |      1400 |     0.714 |        5.9 | 6.4e-07 |      20 |
+ | Array::Set::set_diff    | 0.05   |      3200 |     0.31  |       14   | 9.6e-07 |      20 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table3#
@@ -172,32 +176,32 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_diff    | 0.02   |        57 |     18    |          1 | 7.4e-05 |      22 |
- | Set::Scalar::difference |        |       300 |      3    |          6 |   3e-05 |      20 |
- | Set::Object::difference |        |      1400 |      0.73 |         24 | 8.5e-07 |      20 |
- | Array::Set::set_diff    | 0.05   |      2600 |      0.38 |         46 | 4.8e-07 |      20 |
+ | Array::Set::set_diff    | 0.02   |        55 |     18    |       1    | 3.2e-05 |      20 |
+ | Set::Scalar::difference |        |       357 |      2.8  |       6.55 | 2.2e-06 |      20 |
+ | Set::Object::difference |        |      1400 |      0.73 |      25    | 7.5e-07 |      20 |
+ | Array::Set::set_diff    | 0.05   |      3000 |      0.33 |      55    | 4.8e-07 |      20 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table4#
  {dataset=>"1000_1000"}
- +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | participant             | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_diff    | 0.02   |        14 |    73     |        1   | 8.9e-05 |      20 |
- | Set::Scalar::difference |        |       232 |     4.31  |       17   | 1.6e-06 |      20 |
- | Set::Object::difference |        |      1210 |     0.823 |       88.9 | 2.5e-07 |      22 |
- | Array::Set::set_diff    | 0.05   |      1950 |     0.512 |      143   | 2.4e-07 |      24 |
- +-------------------------+--------+-----------+-----------+------------+---------+---------+
+ +-------------------------+--------+-----------+-----------+------------+-----------+---------+
+ | participant             | modver | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +-------------------------+--------+-----------+-----------+------------+-----------+---------+
+ | Array::Set::set_diff    | 0.02   |        10 |    70     |        1   |   0.00073 |      20 |
+ | Set::Scalar::difference |        |       254 |     3.94  |       17.6 | 2.2e-06   |      20 |
+ | Set::Object::difference |        |      1190 |     0.842 |       82.5 | 6.9e-07   |      20 |
+ | Array::Set::set_diff    | 0.05   |      2000 |     0.6   |      100   | 6.2e-06   |      22 |
+ +-------------------------+--------+-----------+-----------+------------+-----------+---------+
 
  #table5#
  {dataset=>"100_1"}
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_diff    | 0.02   |      3300 |       300 |        1   | 4.2e-07 |      21 |
- | Set::Scalar::difference |        |      3310 |       303 |        1   | 2.1e-07 |      21 |
- | Set::Object::difference |        |     14000 |        72 |        4.2 | 1.3e-07 |      21 |
- | Array::Set::set_diff    | 0.05   |     33000 |        31 |        9.9 | 4.4e-08 |      29 |
+ | Array::Set::set_diff    | 0.02   |      3100 |     320   |        1   | 1.8e-06 |      26 |
+ | Set::Scalar::difference |        |      3400 |     300   |        1.1 | 3.9e-07 |      30 |
+ | Set::Object::difference |        |     13000 |      79   |        4.1 | 1.2e-07 |      23 |
+ | Array::Set::set_diff    | 0.05   |     32700 |      30.6 |       10.6 | 1.2e-08 |      25 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table6#
@@ -205,10 +209,10 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_diff    | 0.02   |      2440 |     410   |       1    |   2e-07 |      22 |
- | Set::Scalar::difference |        |      3010 |     332   |       1.24 | 1.9e-07 |      26 |
- | Set::Object::difference |        |     13000 |      74   |       5.5  | 1.2e-07 |      25 |
- | Array::Set::set_diff    | 0.05   |     31200 |      32.1 |      12.8  | 1.2e-08 |      26 |
+ | Array::Set::set_diff    | 0.02   |      2200 |       460 |       1    | 4.8e-07 |      20 |
+ | Set::Scalar::difference |        |      3050 |       327 |       1.41 | 2.7e-07 |      20 |
+ | Set::Object::difference |        |     12000 |        81 |       5.7  | 1.2e-07 |      26 |
+ | Array::Set::set_diff    | 0.05   |     31000 |        32 |      14    | 5.3e-08 |      20 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table7#
@@ -216,10 +220,10 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_diff    | 0.02   |    1070   |  937      |      1     | 2.7e-07 |      20 |
- | Set::Scalar::difference |        |    1730   |  578      |      1.62  | 4.3e-07 |      20 |
- | Set::Object::difference |        |   12000   |   82      |     11     |   1e-07 |      22 |
- | Array::Set::set_diff    | 0.05   |   22053.2 |   45.3449 |     20.668 |   0     |      26 |
+ | Array::Set::set_diff    | 0.02   |      1000 |    1000   |       1    | 1.7e-05 |      21 |
+ | Set::Scalar::difference |        |      1760 |     567   |       1.81 | 2.1e-07 |      20 |
+ | Set::Object::difference |        |     11300 |      88.6 |      11.6  |   8e-08 |      20 |
+ | Array::Set::set_diff    | 0.05   |     22600 |      44.3 |      23.2  | 1.1e-08 |      28 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table8#
@@ -227,10 +231,10 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::difference |        |     12000 |     85    |       1    | 1.1e-07 |      20 |
- | Array::Set::set_diff    | 0.02   |     28000 |     35    |       2.4  | 5.4e-08 |      31 |
- | Set::Object::difference |        |    100000 |      9.96 |       8.49 | 3.3e-09 |      21 |
- | Array::Set::set_diff    | 0.05   |    210000 |      4.8  |      18    | 6.7e-09 |      20 |
+ | Set::Scalar::difference |        |     12000 |      86   |        1   |   1e-07 |      22 |
+ | Array::Set::set_diff    | 0.02   |     30000 |      34   |        2.5 | 4.6e-08 |      27 |
+ | Set::Object::difference |        |     88000 |      11   |        7.6 | 1.3e-08 |      20 |
+ | Array::Set::set_diff    | 0.05   |    210000 |       4.8 |       18   | 6.5e-09 |      21 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table9#
@@ -238,10 +242,10 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::difference |        |      9000 |   111     |      1     | 5.3e-08 |      20 |
- | Array::Set::set_diff    | 0.02   |     22000 |    45     |      2.5   | 5.2e-08 |      21 |
- | Set::Object::difference |        |     94374 |    10.596 |     10.485 | 3.8e-11 |      20 |
- | Array::Set::set_diff    | 0.05   |    171000 |     5.85  |     19     | 5.7e-09 |      27 |
+ | Set::Scalar::difference |        |      8800 |     110   |       1    | 1.8e-07 |      27 |
+ | Array::Set::set_diff    | 0.02   |     20500 |      48.8 |       2.33 | 4.6e-08 |      27 |
+ | Set::Object::difference |        |     77000 |      13   |       8.7  | 2.7e-08 |      20 |
+ | Array::Set::set_diff    | 0.05   |    150000 |       6.9 |      17    | 1.3e-08 |      20 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table10#
@@ -249,10 +253,10 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::difference |        |   10417.2 |   95.9952 |       1    | 3.7e-11 |      22 |
- | Array::Set::set_diff    | 0.02   |   24000   |   42      |       2.3  | 4.2e-08 |      32 |
- | Set::Object::difference |        |   97300   |   10.3    |       9.34 | 3.3e-09 |      20 |
- | Array::Set::set_diff    | 0.05   |  180000   |    5.4    |      18    | 6.5e-09 |      21 |
+ | Set::Scalar::difference |        |     10000 |     98    |        1   | 1.3e-07 |      21 |
+ | Array::Set::set_diff    | 0.02   |     23000 |     44    |        2.2 | 5.2e-08 |      21 |
+ | Set::Object::difference |        |     80000 |     13    |        7.8 | 2.3e-08 |      20 |
+ | Array::Set::set_diff    | 0.05   |    181000 |      5.52 |       17.7 | 1.3e-09 |      32 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table11#
@@ -260,28 +264,27 @@ Benchmark with C<< bencher -m ArraySet::diff --include-path archive/Array-Set-0.
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant             | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::difference |        |     16200 |     61.7  |        1   | 2.7e-08 |      20 |
- | Array::Set::set_diff    | 0.02   |    130000 |      7.8  |        7.9 | 1.2e-08 |      23 |
- | Set::Object::difference |        |    250000 |      3.9  |       16   | 6.7e-09 |      20 |
- | Array::Set::set_diff    | 0.05   |    502000 |      1.99 |       31   | 6.9e-10 |      29 |
+ | Set::Scalar::difference |        |     16000 |     63    |        1   | 9.9e-08 |      23 |
+ | Array::Set::set_diff    | 0.02   |    130000 |      7.7  |        8.1 | 1.3e-08 |      20 |
+ | Set::Object::difference |        |    240000 |      4.2  |       15   | 9.5e-09 |      22 |
+ | Array::Set::set_diff    | 0.05   |    489000 |      2.04 |       30.8 | 8.3e-10 |      20 |
  +-------------------------+--------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m ArraySet::diff --module-startup >>):
 
  #table12#
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Set::Object         |      16   |                   11.5 |        1   | 5.8e-05 |      20 |
- | Set::Scalar         |      15   |                   10.5 |        1.1 | 2.7e-05 |      20 |
- | Array::Set          |       8.1 |                    3.6 |        2   | 4.7e-05 |      21 |
- | perl -e1 (baseline) |       4.5 |                    0   |        3.7 | 5.8e-06 |      20 |
- +---------------------+-----------+------------------------+------------+---------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Set::Object         | 1.91                         | 5.29               | 19.1           |      17.3 |                   11.6 |        1   | 1.1e-05 |      20 |
+ | Set::Scalar         | 0.82                         | 4.1                | 16             |      17   |                   11.3 |        1   |   4e-05 |      20 |
+ | Array::Set          | 2.2                          | 5.6                | 19             |       9.5 |                    3.8 |        1.8 | 3.6e-05 |      20 |
+ | perl -e1 (baseline) | 1                            | 4.4                | 16             |       5.7 |                    0   |        3   | 1.5e-05 |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -307,7 +310,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
