@@ -1,7 +1,7 @@
 package Bencher::Scenario::ArraySet::intersect;
 
-our $DATE = '2016-09-16'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -57,7 +57,7 @@ Bencher::Scenario::ArraySet::intersect - Benchmark intersect operation
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::ArraySet::intersect (from Perl distribution Bencher-Scenarios-ArraySet), released on 2016-09-16.
+This document describes version 0.003 of Bencher::Scenario::ArraySet::intersect (from Perl distribution Bencher-Scenarios-ArraySet), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -71,6 +71,10 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
@@ -150,10 +154,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_intersect | 0.02   |       306 |     3.27  |       1    | 3.1e-06 |      36 |
- | Set::Scalar::intersection |        |       418 |     2.39  |       1.37 |   2e-06 |      20 |
- | Set::Object::intersection |        |      1170 |     0.855 |       3.82 | 6.2e-07 |      21 |
- | Array::Set::set_intersect | 0.05   |      5800 |     0.173 |      18.9  | 4.8e-08 |      25 |
+ | Array::Set::set_intersect | 0.02   |       300 |     3     |       1    | 4.1e-05 |      20 |
+ | Set::Scalar::intersection |        |       400 |     2.5   |       1.3  | 1.6e-05 |      23 |
+ | Set::Object::intersection |        |      1200 |     0.835 |       4.02 | 4.8e-07 |      20 |
+ | Array::Set::set_intersect | 0.05   |      5500 |     0.18  |      18    | 2.5e-07 |      22 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table2#
@@ -161,10 +165,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_intersect | 0.02   |       327 |     3.06  |       1    | 4.3e-07 |      20 |
- | Set::Scalar::intersection |        |       400 |     2.5   |       1.2  | 3.6e-06 |      20 |
- | Set::Object::intersection |        |      1150 |     0.87  |       3.51 | 6.9e-07 |      20 |
- | Array::Set::set_intersect | 0.05   |      5630 |     0.178 |      17.2  | 4.6e-08 |      27 |
+ | Array::Set::set_intersect | 0.02   |       320 |     3.1   |        1   | 6.9e-06 |      20 |
+ | Set::Scalar::intersection |        |       410 |     2.4   |        1.3 | 3.1e-06 |      20 |
+ | Set::Object::intersection |        |      1100 |     0.9   |        3.4 | 3.8e-06 |      32 |
+ | Array::Set::set_intersect | 0.05   |      5430 |     0.184 |       16.8 |   5e-08 |      23 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table3#
@@ -172,10 +176,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_intersect | 0.02   |       295 |     3.39  |       1    | 2.4e-06 |      20 |
- | Set::Scalar::intersection |        |       367 |     2.73  |       1.24 | 2.7e-06 |      20 |
- | Set::Object::intersection |        |      1100 |     0.9   |       3.8  | 9.1e-07 |      20 |
- | Array::Set::set_intersect | 0.05   |      4440 |     0.225 |      15    | 2.1e-07 |      20 |
+ | Array::Set::set_intersect | 0.02   |       290 |     3.4   |        1   | 5.5e-06 |      20 |
+ | Set::Scalar::intersection |        |       370 |     2.7   |        1.3 | 3.6e-06 |      20 |
+ | Set::Object::intersection |        |      1130 |     0.884 |        3.9 | 6.9e-07 |      20 |
+ | Array::Set::set_intersect | 0.05   |      4440 |     0.225 |       15.3 | 2.1e-07 |      21 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table4#
@@ -183,10 +187,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_intersect | 0.02   |       130 |      7.5  |       1    | 2.9e-05 |      20 |
- | Set::Scalar::intersection |        |       257 |      3.89 |       1.93 | 1.7e-06 |      20 |
- | Set::Object::intersection |        |       920 |      1.09 |       6.92 | 7.1e-07 |      22 |
- | Array::Set::set_intersect | 0.05   |      1470 |      0.68 |      11.1  | 4.8e-07 |      20 |
+ | Array::Set::set_intersect | 0.02   |       130 |     7.7   |        1   | 1.5e-05 |      21 |
+ | Set::Scalar::intersection |        |       250 |     3.9   |        1.9 |   9e-06 |      20 |
+ | Set::Object::intersection |        |       850 |     1.2   |        6.5 | 5.8e-06 |      36 |
+ | Array::Set::set_intersect | 0.05   |      1480 |     0.677 |       11.3 | 2.7e-07 |      20 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table5#
@@ -194,10 +198,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::intersection |        |      2230 |       448 |        1   |   2e-07 |      22 |
- | Array::Set::set_intersect | 0.02   |      2900 |       340 |        1.3 |   2e-06 |      20 |
- | Set::Object::intersection |        |     11000 |        88 |        5.1 |   2e-07 |      22 |
- | Array::Set::set_intersect | 0.05   |     63000 |        16 |       28   | 2.3e-08 |      27 |
+ | Set::Scalar::intersection |        |      1900 |       520 |       1    | 3.1e-06 |      20 |
+ | Array::Set::set_intersect | 0.02   |      3130 |       319 |       1.62 | 2.3e-07 |      26 |
+ | Set::Object::intersection |        |     12000 |        85 |       6.1  | 1.1e-07 |      20 |
+ | Array::Set::set_intersect | 0.05   |     60000 |        20 |      30    | 2.5e-07 |      20 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table6#
@@ -205,10 +209,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::intersection |        |      2140 |     468   |       1    | 2.7e-07 |      20 |
- | Array::Set::set_intersect | 0.02   |      2580 |     388   |       1.21 | 2.4e-07 |      24 |
- | Set::Object::intersection |        |     11000 |      91.1 |       5.14 | 8.9e-08 |      29 |
- | Array::Set::set_intersect | 0.05   |     49400 |      20.2 |      23.1  | 6.2e-09 |      23 |
+ | Set::Scalar::intersection |        |      2100 |       480 |        1   |   2e-06 |      21 |
+ | Array::Set::set_intersect | 0.02   |      2800 |       350 |        1.4 | 3.7e-07 |      27 |
+ | Set::Object::intersection |        |     12000 |        87 |        5.5 |   1e-07 |      21 |
+ | Array::Set::set_intersect | 0.05   |     46000 |        22 |       22   | 5.2e-08 |      21 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table7#
@@ -216,10 +220,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Array::Set::set_intersect | 0.02   |      1360 |       734 |       1    | 2.6e-07 |      21 |
- | Set::Scalar::intersection |        |      1550 |       646 |       1.14 | 3.7e-07 |      20 |
- | Set::Object::intersection |        |      9200 |       110 |       6.7  | 2.1e-07 |      20 |
- | Array::Set::set_intersect | 0.05   |     17000 |        60 |      12    |   8e-08 |      20 |
+ | Array::Set::set_intersect | 0.02   |      1490 |     669   |        1   | 6.4e-07 |      20 |
+ | Set::Scalar::intersection |        |      1600 |     640   |        1   | 7.5e-07 |      29 |
+ | Set::Object::intersection |        |      9600 |     100   |        6.4 | 1.7e-07 |      30 |
+ | Array::Set::set_intersect | 0.05   |     15700 |      63.6 |       10.5 | 2.7e-08 |      20 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table8#
@@ -227,10 +231,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::intersection |        |      9900 |    100    |        1   | 1.1e-07 |      20 |
- | Array::Set::set_intersect | 0.02   |     25000 |     39    |        2.6 | 6.7e-08 |      20 |
- | Set::Object::intersection |        |     83000 |     12    |        8.4 | 1.3e-08 |      20 |
- | Array::Set::set_intersect | 0.05   |    306000 |      3.27 |       30.8 | 1.5e-09 |      26 |
+ | Set::Scalar::intersection |        |      8600 |    120    |       1    | 2.6e-07 |      21 |
+ | Array::Set::set_intersect | 0.02   |     25500 |     39.2  |       2.98 | 1.3e-08 |      20 |
+ | Set::Object::intersection |        |     83700 |     12    |       9.78 |   1e-08 |      20 |
+ | Array::Set::set_intersect | 0.05   |    291000 |      3.44 |      34    | 1.7e-09 |      20 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table9#
@@ -238,10 +242,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::intersection |        |      8300 |   120     |       1    | 1.7e-07 |      31 |
- | Array::Set::set_intersect | 0.02   |     14000 |    72     |       1.7  | 1.1e-07 |      28 |
- | Set::Object::intersection |        |     74000 |    14     |       8.8  | 2.7e-08 |      20 |
- | Array::Set::set_intersect | 0.05   |    132200 |     7.563 |      15.91 | 9.8e-11 |      20 |
+ | Set::Scalar::intersection |        |    7500   |  130      |    1       | 2.5e-07 |      23 |
+ | Array::Set::set_intersect | 0.02   |   13954.6 |   71.6607 |    1.85522 |   0     |      20 |
+ | Set::Object::intersection |        |   74700   |   13.4    |    9.93    | 5.8e-09 |      26 |
+ | Array::Set::set_intersect | 0.05   |  137000   |    7.28   |   18.3     | 3.3e-09 |      20 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table10#
@@ -249,10 +253,10 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::intersection |        |      9120 |    110    |       1    | 5.3e-08 |      20 |
- | Array::Set::set_intersect | 0.02   |     18000 |     55    |       2    |   9e-08 |      28 |
- | Set::Object::intersection |        |     76300 |     13.1  |       8.37 | 6.5e-09 |      21 |
- | Array::Set::set_intersect | 0.05   |    188000 |      5.32 |      20.6  | 1.4e-09 |      28 |
+ | Set::Scalar::intersection |        |      8200 |    120    |     1      | 2.6e-07 |      21 |
+ | Array::Set::set_intersect | 0.02   |     18000 |     55    |     2.2    | 1.1e-07 |      29 |
+ | Set::Object::intersection |        |     77337 |     12.93 |     9.4076 | 5.8e-11 |      20 |
+ | Array::Set::set_intersect | 0.05   |    190000 |      5.2  |    23      | 6.7e-09 |      20 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
  #table11#
@@ -260,28 +264,27 @@ Benchmark with C<< bencher -m ArraySet::intersect --include-path archive/Array-S
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant               | modver | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
- | Set::Scalar::intersection |        |     15000 |   65      |      1     | 9.5e-08 |      25 |
- | Array::Set::set_intersect | 0.02   |     92000 |   11      |      5.9   | 1.3e-08 |      21 |
- | Set::Object::intersection |        |    205000 |    4.89   |     13.2   | 1.5e-09 |      26 |
- | Array::Set::set_intersect | 0.05   |    511340 |    1.9556 |     33.082 | 1.1e-11 |      24 |
+ | Set::Scalar::intersection |        |     14000 |      72   |        1   | 1.1e-07 |      20 |
+ | Array::Set::set_intersect | 0.02   |     91000 |      11   |        6.6 | 1.3e-08 |      22 |
+ | Set::Object::intersection |        |    200000 |       5   |       10   | 5.5e-08 |      20 |
+ | Array::Set::set_intersect | 0.05   |    430000 |       2.3 |       31   | 6.6e-09 |      26 |
  +---------------------------+--------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m ArraySet::intersect --module-startup >>):
 
  #table12#
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Set::Object         |      16   |                   11.5 |       1    |   1e-05 |      20 |
- | Set::Scalar         |      14.9 |                   10.4 |       1.07 | 1.2e-05 |      20 |
- | Array::Set          |       8.2 |                    3.7 |       2    |   4e-05 |      20 |
- | perl -e1 (baseline) |       4.5 |                    0   |       3.5  |   1e-05 |      21 |
- +---------------------+-----------+------------------------+------------+---------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | Set::Object         | 2                            | 5                  | 20             |        20 |                     13 |        1   |   0.00036 |      20 |
+ | Set::Scalar         | 0.82                         | 4.1                | 16             |        17 |                     10 |        1.3 | 7.4e-05   |      20 |
+ | Array::Set          | 2                            | 6                  | 20             |        10 |                      3 |        2   |   0.00034 |      20 |
+ | perl -e1 (baseline) | 1                            | 4                  | 20             |         7 |                      0 |        3   |   0.00012 |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -307,7 +310,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
